# 032

|                                                           | 032-tumble-dryer-td22-b2plus   | 032-000               |
|:----------------------------------------------------------|:-------------------------------|:----------------------|
| bindTime                                                  | 1737708493134                  | 1706691809565         |
| createTime                                                | 0                              | 0                     |
| deviceFeatureCode                                         | tumble-dryer-td22-b2plus       | 000                   |
| deviceFeatureName                                         | TUMBLE-DRYER-TD22-B2PLUS       | G-dryer               |
| deviceId                                                  | <redacted>                     | <redacted>            |
| deviceNickName                                            | Tumble Dryer                   | Gorenje Dryer DPNA83W |
| deviceTypeCode                                            | 032                            | 032                   |
| deviceTypeName                                            |                                |                       |
| isShow                                                    | 1                              |                       |
| offlineState                                              | 1                              | 1                     |
| puid                                                      | <redacted>                     | <redacted>            |
| role                                                      | 1                              | 1                     |
| roomId                                                    | 7040508                        | 3646057               |
| roomName                                                  | Vasketøjsrum                   | default_room          |
| seq                                                       | 0                              | 1                     |
| statusList.AdaptTech_setting                              | 0                              | 2                     |
| statusList.Alarm_1                                        | 0                              | 1                     |
| statusList.Alarm_10                                       | 1                              | 1                     |
| statusList.Alarm_11                                       | 1                              | 1                     |
| statusList.Alarm_12                                       | 1                              | 1                     |
| statusList.Alarm_13                                       | 0                              |                       |
| statusList.Alarm_2                                        | 0                              | 1                     |
| statusList.Alarm_3                                        | 0                              | 1                     |
| statusList.Alarm_4                                        | 0                              | 1                     |
| statusList.Alarm_5                                        | 1                              | 1                     |
| statusList.Alarm_6                                        | 0                              | 1                     |
| statusList.Alarm_7                                        | 1                              | 1                     |
| statusList.Alarm_8                                        | 1                              | 1                     |
| statusList.Alarm_9                                        | 1                              | 1                     |
| statusList.AntiCrease_setting                             | 3                              | 1                     |
| statusList.Appliance_status                               | 5                              | 5                     |
| statusList.Bundling_Humidity                              | 255                            | 255                   |
| statusList.Bundling_Temperature                           | 255                            | 255                   |
| statusList.Bundling_sensor_setting_status                 | 0                              | 0                     |
| statusList.Child_Lock_status                              | 1                              | 1                     |
| statusList.Condensed_watermode                            | 1                              | 1                     |
| statusList.Current_programphase                           | 1                              | 1                     |
| statusList.DelayStart_DelayEnd_duration_inminutes         | 0                              | 0                     |
| statusList.DelayStart_DelayEnd_mode                       | 1                              | 1                     |
| statusList.DelayStart_DelayEnd_remaining_timein_minutes   | 0                              | 0                     |
| statusList.Delay_duration_inminutes                       | 65535                          | 0                     |
| statusList.Door_status                                    | 1                              | 1                     |
| statusList.Error_0                                        | 1                              | 1                     |
| statusList.Error_1                                        | 1                              | 1                     |
| statusList.Error_10                                       | 1                              | 1                     |
| statusList.Error_11                                       | 1                              | 1                     |
| statusList.Error_12                                       | 1                              | 1                     |
| statusList.Error_13                                       | 1                              | 1                     |
| statusList.Error_14                                       | 1                              | 1                     |
| statusList.Error_15                                       | 1                              | 1                     |
| statusList.Error_16                                       | 1                              | 1                     |
| statusList.Error_17                                       | 0                              |                       |
| statusList.Error_18                                       | 0                              |                       |
| statusList.Error_2                                        | 1                              | 1                     |
| statusList.Error_3                                        | 1                              | 1                     |
| statusList.Error_4                                        | 1                              | 1                     |
| statusList.Error_5                                        | 1                              | 1                     |
| statusList.Error_6                                        | 1                              | 1                     |
| statusList.Error_7                                        | 1                              | 1                     |
| statusList.Error_8                                        | 1                              | 1                     |
| statusList.Error_9                                        | 1                              | 1                     |
| statusList.ExtraDry_setting                               | 1                              | 1                     |
| statusList.Float_switch                                   | 1                              | 1                     |
| statusList.Fota                                           | 0                              | 0                     |
| statusList.HardPairingStatus                              | 0                              | 0                     |
| statusList.Humidity_sensor                                | 0                              | 0                     |
| statusList.Language_setting                               | 0                              |                       |
| statusList.Logo_setting_status                            | 0                              | 0                     |
| statusList.NTC_sensor_1                                   | 255                            | 0                     |
| statusList.NTC_sensor_2                                   | 125                            | 54                    |
| statusList.Reed_switch                                    | 1                              | 1                     |
| statusList.Remote_control_mode_monitoring                 | 1                              | 1                     |
| statusList.Remote_control_monitoring_set_commands         | 1                              | 1                     |
| statusList.Remote_control_monitoring_set_commands_actions | 0                              | 0                     |
| statusList.Selected_program_AntiCrease_status             | 2                              | 1                     |
| statusList.Selected_program_ExtraDry_status               | 1                              | 1                     |
| statusList.Selected_program_ID                            | 0                              | 255                   |
| statusList.Selected_program_SteamFinish                   | 0                              | 0                     |
| statusList.Selected_program_mode2                         | 0                              |                       |
| statusList.Selected_program_mode_status                   | 1                              | 1                     |
| statusList.Selected_programduration_inminutes             | 195                            | 0                     |
| statusList.Selected_programremaining_time_inminutes       | 195                            | 0                     |
| statusList.Session_pairing_active                         | 0                              | 0                     |
| statusList.Session_pairing_setting                        | 0                              | 0                     |
| statusList.Soft_pairing_setting                           | 1                              | 1                     |
| statusList.Sound_settings                                 | 4                              | 3                     |
| statusList.UTC_DateTime_BDC_DelayStart_DelayEnd_timestamp | 16679/02/18T23:47:45           | 16679/02/18T23:47:45  |
| statusList.Washer_to_Dryer_available_for_hours_v          | 255                            | 1                     |
| statusList.Washer_to_Dryer_program_ID                     | 255                            | 254                   |
| statusList.Washer_to_Dryersetting_status                  | 0                              | 0                     |
| statusList.Washer_to_dryerwizard_trigger_status           | 0                              | 1                     |
| statusList.Water_level_switch                             | 0                              | 1                     |
| statusList.daily_energy_kwh                               | 0                              | 0                     |
| useTime                                                   | 1737129891904                  | 1706691809544         |
| wifiId                                                    | <redacted>                     | <redacted>            |

## Generated from

- [`032`](032-tumble-dryer-td22-b2plus.json)
- [`032`](032-000.json)
